 local agent_helper = require(AGENT_PATH .. "agent_helper")

AgentAdapter = {
	is_init = false,
	login_callback = nil,
	force_logout = false,
	login_verify_url = "cls.mg21.youyannet.com/ac2/login_verify.php",
	notifyUrl = "http://cls.mg21.youyannet.com/ac2/pay.php",
	uid = "",
}

-- 初始化
function AgentAdapter:Init()
	if self.is_init then return end
	self.uid = string.gsub((AdapterToLua:getInstance():getDataCache("PRVE_ACCOUNT_NAME") or ""), self:GetSpid() .. "_", "")
	self.is_init = true
	AgentMs:InitLocalPush()

	PlatformBinder:JsonBind("call_agent_logout", function(arg)
		self:LogoutCallback(arg)
		return true
	end)
end

--获得游戏名字
function AgentAdapter:GetGameName()
	return Language.Common.GameName[17]
end

--获得logo资源名
function AgentAdapter:GetLogoResName()
	return "agentres/logo.png"
end


-- 平台ID
function AgentAdapter:GetSpid()
	return "ac2"
end

-- 平台帐号唯一标识
function AgentAdapter:GetOpenId()
	return self.uid
end

-- 加前辍的平台帐号，全平台唯一
function AgentAdapter:GetPlatName()
	return "ac2_" .. self.uid
end

function AgentAdapter:LoginCallback(result)
	-- if "true" == result then return true end

	local json_obj = cjson.decode(result)
	if nil == json_obj or nil == json_obj.uid or nil == json_obj.sid or nil == json_obj.ucid then return end
	local uid = json_obj.uid
	local sid = json_obj.sid
	local ucid = json_obj.ucid

	local verify_callback = function(url, arg, data, size)
		self.is_login_verify_ing = false
		if size <= 0 then
			Log("verify_callback, fail:size<=0")
			return
		end

		local ret_t = cjson.decode(data)
		if nil == ret_t or 0 ~= ret_t.ret or nil == ret_t.user then
			Log("verify_callback, fail")
			return
		end

		self.uid = ret_t.user.uid
		LoginController.Instance:SetLoginUserData(self:GetPlatName(), ret_t.user)
		self.login_callback(self:GetPlatName())
	end

	self.is_login_verify_ing = true
	
	local now_server_time = math.floor(GLOBAL_CONFIG.server_info.server_time + (Status.NowTime - GLOBAL_CONFIG.client_time))
	local sign = UtilEx:md5Data(self:GetSpid() .. sid .. uid .. ucid .. now_server_time .. LOGIN_VERIFY_KEY)
	local real_url = string.format("%s?spid=%s&sid=%s&uid=%s&ucid=%s&time=%s&sign=%s", self.login_verify_url, self:GetSpid(), sid, uid, ucid, now_server_time, sign)
	Log("start verify login: url=" .. real_url)
	HttpClient:Request(real_url, "", verify_callback)

	return false
end

function AgentAdapter:Login(callback)
	self.login_callback = callback
	agent_helper:Login(LUA_CALLBACK(self, self.LoginCallback))
end

function AgentAdapter:LogoutCallback(result)
	self.uid = ""
	if not LoginController.Instance:AgentLoginViewIsOpen() then
		ReStart()
	end
	return true
end

function AgentAdapter:Logout()
	self.force_logout = true
	agent_helper:Logout()
end

function AgentAdapter:Pay(role_id, role_name, amount, server_id, callback)
	if self.uid == "" then
		SysMsgCtrl.Instance:ErrorRemind("uid为空，请联系客服")
		return
	end
	local json_obj = {}
	json_obj.amount = amount .. ".00"
	json_obj.goodsname = "元宝"
	json_obj.goodsdesc = "元宝"
	json_obj.order = server_id .. "_" .. self.uid .. "_" .. os.time()
	json_obj.notifyUrl = self.notifyUrl
	agent_helper:Pay(cjson.encode(json_obj), callback)
end

function AgentAdapter:SubmitRoleData(role_id, role_name, role_level, zone_id, zone_name)
	if self.uid == "" then
		return
	end
	local json_obj = {}
	json_obj.role_id = role_id
	json_obj.role_name = role_name
	json_obj.role_level = role_level
	json_obj.zone_id = zone_id
	json_obj.zone_name = zone_name
	PlatformBinder:JsonCall("call_agent_submit_extend_data", cjson.encode(json_obj))
end

-- 是否支持动态下载
function AgentAdapter:IsDynamicDownloadRes()
	return true
end