AgentAdapter = {
	is_init = false,
	login_flag = false,
	user_id = "",
	session_id = "",
	pay_type_url = "cls.mg21.youyannet.com/ac4/pay_type.php",
}

-- 平台ID
function AgentAdapter:GetSpid()
	return "ac4"
end

-- 平台帐号唯一标识
function AgentAdapter:GetOpenId()
	return self.user_id
end

-- 加前辍的平台帐号，全平台唯一
function AgentAdapter:GetPlatName()
	return "ac4_" .. self.user_id
end

--获得游戏名字
function AgentAdapter:GetGameName()
	return Language.Common.GameName[17]
end

--获得logo资源名
function AgentAdapter:GetLogoResName()
	return "agentres/logo.png"
end

-- 初始化
function AgentAdapter:Init()
	if self.is_init then return end
	self.is_init = true
	self.user_id = string.gsub((AdapterToLua:getInstance():getDataCache("PRVE_ACCOUNT_NAME") or ""), self:GetSpid() .. "_", "")
	
	AgentMs:InitLocalPush()

	PlatformBinder:JsonBind("call_agent_login", function(arg)
		self:LoginCallback(arg)
		return true
	end)

	PlatformBinder:JsonBind("call_agent_logout", function(arg)
		self:LogoutCallback(arg)
		return true
	end)

	PlatformBinder:JsonBind("call_agent_pay", function(arg)
		self:PayCallback(arg)
		return true
	end)

	GlobalEventSystem:Bind(LoginEventType.ENTER_GAME_SERVER_SUCC, function()
		self:SetUserInfo()
	end)
end

-- 登录
function AgentAdapter:Login()
	if self.login_flag and "" ~= self.user_id then
		LoginController.Instance:LoginPlatSucc(self:GetPlatName(), self.session_id)
		return
	end

	PlatformBinder:JsonCall("call_agent_login")
end

-- 登出
function AgentAdapter:Logout()
	PlatformBinder:JsonCall("call_agent_logout")
end

-- 是否有管理中心
function AgentAdapter:IsHasManagerCenter()
	return false
end

-- 打开管理中心
function AgentAdapter:OpenManagerCenter()
	if self:IsHasManagerCenter() then
		PlatformBinder:JsonCall("call_agent_manager_center")
	end
end

-- 悬浮按钮
function AgentAdapter:ShowFloatButton()
end

-----------------------------------------
--充值相关
-----------------------------------------
function AgentAdapter:Pay(role_id, role_name, amount, server_id, callback)

	local verify_callback = function(url, arg, data, size)	
		local ret_t = cjson.decode(data)
		if ret_t ~= nil and ret_t.pay_type == "0" then
			--百度支付
			AgentAdapter:BdPay(role_id, role_name, amount, server_id, callback)
		elseif ret_t ~= nil and ret_t.pay_type == "1" then
			--汇娱支付
			AgentAdapter:HyPay(role_id, role_name, amount, server_id, callback)
		end
	end
	HttpClient:Request(self.pay_type_url, "", verify_callback)
end

-- 百度支付
function AgentAdapter:BdPay(role_id, role_name, amount, server_id, callback)
	
	local arg_t = {
		["product_name"] = amount * 10 .. "元宝",
		["amount"] = amount,
		["order_id"] = server_id .. "_" .. role_id .. "_" .. os.time(),
	}
	local arg = cjson.encode(arg_t)
	PlatformBinder:JsonCall("call_agent_pay", arg)
end

-- 汇娱支付
function AgentAdapter:HyPay(role_id, role_name, amount, server_id, callback)
	
end

function AgentAdapter:OnClickBackLogin()
	PlatformBinder:JsonCall("call_agent_logout")
end

function AgentAdapter:SetUserInfo()

end

-- 登录回调
function AgentAdapter:LoginCallback(arg)
	local ret_t = cjson.decode(arg)
	if 1 == ret_t.ret then	-- 切换账号
		ReStart()
		return
	end

	self.login_flag = true
	self.user_id = ret_t.user_id
	self.session_id = ret_t.session_id

	LoginController.Instance:LoginPlatSucc(self:GetPlatName(), self.session_id)
end

-- 登出回调
function AgentAdapter:LogoutCallback(arg)
	self.login_flag = false
	self.user_id = ""
	self.session_id = ""
	if not LoginController.Instance:AgentLoginViewIsOpen() then
		ReStart()
	end
end

-- 支付回调
function AgentAdapter:PayCallback(arg)
	
end


--退出
function PlatformAdapter:OpenExitDialog()

	--通知SDK退出
		PlatformBinder:JsonCall("call_agent_exit", "", "", function(result) 
		if "true" == result then
			AdapterToLua:endGame()
		end
	end)

end
