local agent_helper = require(AGENT_PATH .. "agent_helper")

function PlatformAdapter:OpenExitDialog()
	agent_helper:Exit(function(result) 
		if "true" == result then
			AdapterToLua:endGame()
		end
	end)
end

AgentAdapter = {
	login_callback = nil,
	force_logout = false,
	is_login_verify_ing = false,
	login_verify_url = "cls.mg21.youyannet.com/ah1/login_verify.php",

	uid = "",
}

-- 初始化
function AgentAdapter:Init()
	if self.is_init then return end
	self.is_init = true
	self.uid = string.gsub((AdapterToLua:getInstance():getDataCache("PRVE_ACCOUNT_NAME") or ""), self:GetSpid() .. "_", "")
	AgentMs:InitLocalPush()
end

-- 平台ID
function AgentAdapter:GetSpid()
	return "ah1"
end

-- 平台帐号唯一标识
function AgentAdapter:GetOpenId()
	return self.uid
end

-- 加前辍的平台帐号，全平台唯一
function AgentAdapter:GetPlatName()
	return "ah1_" .. self.uid
end

function AgentAdapter:LoginCallback(result)
	if "true" == result then return true end

	if "exit" == result and agent_helper:GetSessionId() ~= "" then
		local verify_callback = function(url, arg, data, size)
			self.is_login_verify_ing = false
			if size <= 0 then
				Log("verify_callback, fail:size<=0")
				return
			end

			local ret_t = cjson.decode(data)
			if nil == ret_t or 0 ~= ret_t.ret or nil == ret_t.user then
				Log("verify_callback, fail")
				return
			end

			Log("login-verify, success")
			self:ShowFloatButton()
			self.uid = ret_t.user.uid
			LoginController.Instance:SetLoginUserData(self:GetPlatName(), ret_t.user)
			self.login_callback(self:GetPlatName())
		end

		self.is_login_verify_ing = true
		
		local session_id = agent_helper:GetSessionId()
		local now_server_time = math.floor(GLOBAL_CONFIG.server_info.server_time + (Status.NowTime - GLOBAL_CONFIG.client_time))
		local sign = UtilEx:md5Data(self:GetSpid() .. session_id .. now_server_time .. LOGIN_VERIFY_KEY)
		local real_url = string.format("%s?spid=%s&sid=%s&time=%s&sign=%s&device=%s", self.login_verify_url, self:GetSpid(), session_id, now_server_time, sign, tostring(PlatformAdapter.GetPhoneUniqueId()))
		Log("start verify login: url=" .. real_url)
		HttpClient:Request(real_url, "", verify_callback)
	end
	return false
end


--获得游戏名字
function AgentAdapter:GetGameName()
	return Language.Common.GameName[39]
end

--获得logo资源名
function AgentAdapter:GetLogoResName()
	return "agentres/mhqx_logo.png"
end


function AgentAdapter:Login(callback)
	self.login_callback = callback
	if self.is_login_verify_ing then
		SysMsgCtrl.Instance:ErrorRemind("正在登录验证中，请稍等...", true)
		return
	end

	agent_helper:Login(LUA_CALLBACK(self, self.LoginCallback))
end

function AgentAdapter:SwitchAccount(callback)
	self.login_callback = callback
	agent_helper:Logout()
end

function AgentAdapter:LogoutCallback(result)
	if "true" == result then
		self.uid = ""
		if not LoginController.Instance:AgentLoginViewIsOpen() then
			ReStart()
		end
	end
	return true
end

function AgentAdapter:Logout()
	self.force_logout = true
	agent_helper:Logout()
end

function AgentAdapter:UIEventCallback(event)
	if "open" == event then
		--self:ShowFloatButton()
	elseif "close" == event then
		--self:ShowFloatButton()
	end
	return true
end

function AgentAdapter:ShowFloatButton()
	agent_helper:ShowFloatButton(70, 30, true)
end

function AgentAdapter:Pay(role_id, role_name, amount, server_id, callback)

	if GLOBAL_CONFIG.param_list.switch_list.open_chongzhi then
		Log("========open_chongzhi=======2")
		agent_helper:Pay(role_id, role_name, amount, server_id, callback)
	else
		SysMsgCtrl.Instance:ErrorRemind(Language.OpenServer.NotOpenCloseBeta)
	end

	
end






function AgentAdapter:EnterUserCenter()
	agent_helper:EnterUserCenter()
end

agent_helper:SetLogoutCallback(LUA_CALLBACK(AgentAdapter, AgentAdapter.LogoutCallback))
agent_helper:SetUIEventCallback(LUA_CALLBACK(AgentAdapter, AgentAdapter.UIEventCallback))


-- --元宝变化
-- function AgentAdapter:OnMoneyChange(gold)
-- 	Log("OnMoneyChange==================")
-- 	Log(gold)
-- 	PlatformBinder:JsonCall("call_agent_on_money_change", gold)
-- end




-- 创建角色上报
function AgentAdapter:ReportOnCreateRole(role_name)
	self.createRole = true
	self:SubmitInfo(0)
end

-- 进入游戏上报
function AgentAdapter:SubmitRoleData(role_id, role_name, role_level, zone_id, zone_name)
	if self.subit_date_tf == nil and self.createRole == nil then
		self.subit_date_tf = true
		self:SubmitInfo(1)
	end
	
end

--  升级上报
function AgentAdapter:ReportOnRoleLevUp(role_id, role_name, role_level, zone_id, zone_name)
	print("ReportOnRoleLevUp===========")
	self.roleLevelMTime = os.time()
	self:SubmitInfo(2)
end


function AgentAdapter:SubmitInfo(type_x)
	local role_vo = GameVoManager.Instance:GetMainRoleVo()
	local user_vo = GameVoManager.Instance:GetUserVo()

	if role_vo ~= nil and user_vo ~= nil then
		local info = {}
		info.zoneId = tostring(user_vo.plat_server_id)
		info.zoneName = user_vo.plat_server_id .. "服-" .. user_vo.plat_server_name
		info.roleName = role_vo.name
		info.roleId = tostring(role_vo.role_id)
		info.roleLevel = tostring(role_vo.level) or "0"
		--上报创建角色时间
		info.roleCTime = role_vo.create_time or 0
		--升级上报时间
		if type_x == 2 then
			info.roleLevelMTime = self.roleLevelMTime
		end

		print("SubmitInfo==" .. cjson.encode(info))
		agent_helper:SubmitExtendData("loginGameRole", info)
	end
end



--type   0:创建角色 or 只进入游戏时才调用  1:升级
-- function AgentAdapter:SubmitInfo(type)
-- 	local role_vo = GameVoManager.Instance:GetMainRoleVo()
-- 	local user_vo = GameVoManager.Instance:GetUserVo()

-- 	local server_num = user_vo.plat_server_id
	
-- 	if server_num == 1501 then
-- 	   server_num = 1
-- 	end

-- 	if role_vo ~= nil and user_vo ~= nil then
-- 		local info = {}
-- 		if type == 1 then
-- 			--上报角色升级时间
-- 			info.roleLevelMTime = os.time()
-- 		end
-- 		--上报角色创建的时间
-- 		info.roleCTime = os.time()
-- 		info.zoneId = tostring(user_vo.plat_server_id)
-- 		info.zoneName = server_num .. "服-" .. user_vo.plat_server_name
-- 		info.roleName = role_vo.name
-- 		info.roleId = tostring(role_vo.role_id)
-- 		info.roleLevel = tostring(role_vo.level) or "0"

-- 		print("SubmitInfo==" .. cjson.encode(info))
-- 		agent_helper:SubmitExtendData("loginGameRole", info)
-- 	end
-- end

--是否支持动态下载
function AgentAdapter:IsDynamicDownloadRes()
	return true
end