local agent_helper = require(AGENT_PATH .. "agent_helper")

AgentAdapter = {
	is_init = false,
	login_callback = nil,
	force_logout = false,
	is_login_verify_ing = false,
	login_verify_url = "cls.mg21.youyannet.com/ap1/login_verify.php",
	uid = "",
}

-- 初始化
function AgentAdapter:Init()
	if self.is_init then return end
	self.uid = string.gsub((AdapterToLua:getInstance():getDataCache("PRVE_ACCOUNT_NAME") or ""), self:GetSpid() .. "_", "")
	self.is_init = true
	AgentMs:InitLocalPush()
end

-- 平台ID
function AgentAdapter:GetSpid()
	return "ap1"
end

-- 平台帐号唯一标识
function AgentAdapter:GetOpenId()
	return self.uid
end

-- 加前辍的平台帐号，全平台唯一
function AgentAdapter:GetPlatName()
	return "ap1_" .. self.uid
end


--获得游戏名字
function AgentAdapter:GetGameName()
	return Language.Common.GameName[26]
end

--获得logo资源名
function AgentAdapter:GetLogoResName()
	return "agentres/logo.png"
end

function AgentAdapter:LoginCallback(result)
	local json_obj = cjson.decode(result)
	local token = json_obj.token
	self.uid = json_obj.userId

	local verify_callback = function(url, arg, data, size)
		self.is_login_verify_ing = false
		if size <= 0 then
			Log("verify_callback, fail:size<=0")
			return
		end
		local ret_t = cjson.decode(data)
		if nil == ret_t or 0 ~= ret_t.ret or nil == ret_t.user then
			Log("verify_callback, fail")
			return
		end
		print("verify_callback--", ret_t.user.uid)
		self.uid = ret_t.user.uid
		self:ShowFloatButton()
		LoginController.Instance:SetLoginUserData(self:GetPlatName(), ret_t.user)
		self.login_callback(self:GetPlatName())
	end

	self.is_login_verify_ing = true
	AdapterToLua:getInstance():setDataCache("PRVE_ACCOUNT_LW_CODE", self.uid)
	local now_server_time = math.floor(GLOBAL_CONFIG.server_info.server_time + (Status.NowTime - GLOBAL_CONFIG.client_time))
	local sign = UtilEx:md5Data(self:GetSpid() .. self.uid .. now_server_time .. LOGIN_VERIFY_KEY)
	local real_url = string.format("%s?spid=%s&sid=%s&time=%s&sign=%s&token=%s", self.login_verify_url, self:GetSpid(), self.uid, now_server_time, sign, token)
	Log("start verify login: url=" .. real_url)
	HttpClient:Request(real_url, "", verify_callback)
end

function AgentAdapter:Login(callback)
	self.login_callback = callback
	if self.is_login_verify_ing then
		SysMsgCtrl.Instance:ErrorRemind("正在登录验证中，请稍等...", true)
		return
	end

	agent_helper:Login(LUA_CALLBACK(self, self.LoginCallback))
end

function AgentAdapter:SwitchAccount(callback)
	self.login_callback = callback
	agent_helper:Logout()
end

function AgentAdapter:LogoutCallback(result)
	if "true" == result then
		self.uid = ""
		if not LoginController.Instance:AgentLoginViewIsOpen() then
			ReStart()
		end
	end
	return true
end

function AgentAdapter:Logout()
	self.force_logout = true
	agent_helper:Logout()
end

function AgentAdapter:UIEventCallback(event)
	if "open" == event then
		--self:ShowFloatButton()
	elseif "close" == event then
		--self:ShowFloatButton()
	end
	return true
end

function AgentAdapter:ShowFloatButton()
	agent_helper:ShowFloatButton(70, 30, true)
end

function AgentAdapter:Pay(role_id, role_name, amount, server_id, callback)
	local info = {}

	info.subject = "购买" .. (amount * 10) .. "个元宝"
	info.price = amount
	info.orderId = server_id .. "_" .. self:GetPlatName() .. "_" .. os.time()
	info.remark = ""
	agent_helper:Pay(cjson.encode(info), callback)
end

function AgentAdapter:SubmitRoleData(role_id, role_name, role_level, zone_id, zone_name)
	local info = {}
	info.serverId = zone_id
	info.roleName = role_name
	info.level = role_level
	info.zone_name = zone_name
	info.roleMoney = RoleData.Instance.role_info.gold or 0
	agent_helper:SubmitExtendData(cjson.encode(info))
end

function AgentAdapter:EnterUserCenter()
	agent_helper:EnterUserCenter()
end



